﻿// --------------------------------------------------------------------------------------
//
// Kurve91.cs                                                     Ulrich Müller  11.06.06
//                                                                PCS1700 C# 2005 Express
// Modell Kurvenschreiber aus Kasten 30 490 Profi Computing von 1991
// ACHTUNG : Um RobMotoren nutzen zu können wurde it Interfacebelegung leicht modifiziert
//           Siehe Const Interfacebelegung
// Basis ist die Assembly FishFace2005.DLL
//
// --------------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using FishFace40;

namespace BeispieleFishFace {
  public partial class Kurve91 : Form {
    // --- Interfacebelegung --------------
    const int mSchreiber = 1;            // --- zum Endtaster : cLinks
    const int iEndSchreiber = 1;
    const int iImpulsSchreiber = 2;
    const int maxImpulsSchreiber = 280;
    const int mStift = 2;
    const int iEndStift = 3;
    const int mPapier = 3;               // --- vorwärts : cRechts
    const int iImpulsPapier = 6;
    const int aPhoto = 1;
    const int minPhoto = 0;
    const int maxPhoto = 1023;
    const int messBereich = maxPhoto - minPhoto;
    const int messFaktor = (int)(messBereich / maxImpulsSchreiber);
    const int cLinks = 1;
    const int cRechts = 2;
    const int cAus = 0;

    // --- Instanzierung mit Daten für die Industry Robots ---------------
    FishRobot ft = new FishRobot(new int[,] { { mSchreiber, maxImpulsSchreiber}});
    private void PositionAusgabe(object sender, int[] actPos) {
      lblPosition.Text = actPos[actPos.Length - 1].ToString();
    }

    private void Action() {
      // --- Zentrale Steuerungsroutine ---
      InitKurve();
      do {
        AnalogWert();
        ZeilenVorschub();
        ft.Pause(5000);    // --- Messung in 5 Sekundenintervallen ( + Fahrzeiten )
      } while(!ft.Finish());
      ft.NotHalt = false;
      MoveStift(true);
      ft.MoveHome();
    }

    private void InitKurve() {
      MoveStift(true);             // --- Stift auf
      ft.MoveHome();               // --- Schreiber auf Home
      MoveStift(false);            // --- Stift ab
    }

    private void AnalogWert() {
      int aWert = ft.GetAnalog(aPhoto);
      int zPos = (int)((aWert - minPhoto) / messFaktor);
      ft.MoveTo(zPos);
      lblAnalog.Text = aWert.ToString();
    }

    private void ZeilenVorschub() {
      ft.SetMotor(mPapier, cRechts);
      ft.WaitForChange(iImpulsPapier, 1);
      ft.SetMotor(mPapier, cAus);
    }
    private void MoveStift(bool Auf) {
      if (Auf) {
        ft.SetMotor(mStift, cLinks);          // --- Stift heben 
        ft.WaitForInput(iEndStift);
        ft.SetMotor(mStift, cAus);
      }
      else {
        ft.SetMotor(mStift, cLinks);          // --- Stift senken
        ft.WaitForInput(iEndStift, false);
        ft.SetMotor(mStift, cAus);
      }
    }

    #region --- Programm-Kontrolle ---
    public Kurve91() {
      InitializeComponent();
    }

    private void cmdAction_Click(object sender, EventArgs e) {
      // --- Open erstes ROBO an USB oder Intelligent Interface an COM
      //     während des Ablaufs von Action() gesperrt ---------------
      ft.PositionChange += new FishRobot.CommonDelegate(PositionAusgabe);
      try {
        if (cboPortName.SelectedIndex == 0)
          ft.OpenInterface(IFTypen.ftROBO_first_USB, 0);
        else ft.OpenInterface(IFTypen.ftIntelligent_IF, cboPortName.SelectedIndex, 5);
        cmdAction.Enabled = false;
        cmdEnde.Text = "&HALT";
        lblStatus.Text = "--- Bei der Arbeit ---";
        lblHinweis.Text = "--- Ende : HALT-Button oder ESC-Taste ---";

        Action();        // --- Haupt-Routine der Anwendung

        ft.ClearMotors();
      }
      catch (FishFaceException eft) {
        MessageBox.Show(eft.Message, this.Text,
          MessageBoxButtons.OK, MessageBoxIcon.Stop);
      }
      finally {
        ft.CloseInterface();
        cmdAction.Enabled = true;
        cmdEnde.Text = "&ENDE";
        lblStatus.Text = "--- Auf ein Neues ---";
        lblHinweis.Text = "Nochmal : ACTION, sonst ENDE oder ESC-Taste";
        cmdAction.Focus();
      }
    }

    private void cmdEnde_Click(object sender, EventArgs e) {
      // --- Programmende nur, wenn Action nicht läuft ---
      if (cmdEnde.Text == "&HALT") ft.NotHalt = true; else this.Close();
    }

    private void formLoad(object sender, EventArgs e) {
      // --- Default-Interface : Erstes ROBO Interface an USB ----
      cboPortName.SelectedIndex = 0;
    }

    private void formClosing(object sender, FormClosingEventArgs e) {
      // --- Wenn Action läuft, wird ein Programmabbruch über (x) unterbunden ------
      if (cmdEnde.Text == "&HALT") e.Cancel = true;
    }
    #endregion
  }
}